@@ -12,13 +12,13 @@ use {
     },
 };
 
-pub(crate) struct SelectVoteAndResetForkResult {
+pub struct SelectVoteAndResetForkResult {
     pub vote_bank: Option<(Arc<Bank>, SwitchForkDecision)>,
     pub reset_bank: Option<Arc<Bank>>,
     pub heaviest_fork_failures: Vec<HeaviestForkFailures>,
 }
 
-pub(crate) trait ForkChoice {
+pub trait ForkChoice {
     type ForkChoiceKey;
     fn compute_bank_stats(
         &mut self,
@@ -42,5 +42,10 @@ pub(crate) trait ForkChoice {
 
     fn mark_fork_invalid_candidate(&mut self, invalid_slot: &Self::ForkChoiceKey);
 
-    fn mark_fork_valid_candidate(&mut self, valid_slot: &Self::ForkChoiceKey);
+    /// Returns any newly duplicate confirmed ancestors of `valid_slot` up to and including
+    /// `valid_slot` itself
+    fn mark_fork_valid_candidate(
+        &mut self,
+        valid_slot: &Self::ForkChoiceKey,
+    ) -> Vec<Self::ForkChoiceKey>;
 }
